@@ -1,6 +1,6 @@
 package App::PerlWatcher::Engine;
 {
-  $App::PerlWatcher::Engine::VERSION = '0.16';
+  $App::PerlWatcher::Engine::VERSION = '0.17';
 }
 # ABSTRACT: Creates Watchers and lets them  notify Frontend with their's Statuses
 
@@ -11,8 +11,7 @@ use warnings;
 use AnyEvent;
 use Carp;
 use Class::Load ':all';
-use Data::Dumper;
-use Devel::Comments;
+use Smart::Comments -ENV;
 use File::Spec;
 use Moo;
 use Path::Class qw(file);
@@ -138,7 +137,7 @@ App::PerlWatcher::Engine - Creates Watchers and lets them  notify Frontend with
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
