@@ -1,6 +1,6 @@
 package App::PerlWatcher::Status;
 {
-  $App::PerlWatcher::Status::VERSION = '0.16';
+  $App::PerlWatcher::Status::VERSION = '0.17';
 }
 # ABSTRACT: Represents the result of single watcher poll
 
@@ -9,8 +9,7 @@ use strict;
 use warnings;
 
 use Carp;
-use Data::Dumper;
-use Devel::Comments;
+use Smart::Comments -ENV;
 use Moo;
 
 use App::PerlWatcher::Level;
@@ -102,7 +101,7 @@ App::PerlWatcher::Status - Represents the result of single watcher poll
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 ATTRIBUTES
 
