@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher;
 {
-  $App::PerlWatcher::Watcher::VERSION = '0.16';
+  $App::PerlWatcher::Watcher::VERSION = '0.17';
 }
 # ABSTRACT: Observes some external source of events and emits the result of polling them
 
@@ -13,7 +13,7 @@ use App::PerlWatcher::Status;
 use aliased 'App::PerlWatcher::WatcherMemory';
 use Carp;
 use Data::Dump::Filtered qw/dump_filtered/;
-use Devel::Comments;
+use Smart::Comments -ENV;
 use Digest::MD5 qw(md5_base64);
 use List::Util qw( max );
 use Storable qw/freeze/;
@@ -77,14 +77,26 @@ sub _build_memory {
 sub _build_unique_id {
     my $self = shift;
     my $class = ref($self);
-    my $filter = sub {
+    # Filter strips down the subroutine references
+    # and transforms hashes to arrays sorted by keys.
+    # this is needed to always have the same string
+    # for the same config, any change will lead
+    # to change of md5, and the id will be different.
+    my $filter; $filter = sub {
         my($ctx, $object_ref) = @_;
-        return (ref($object_ref) eq 'CODE') ? { object => 'FILTERED' } : undef;
+        my $ref_type = ref($object_ref);
+        return { object => 'FILTERED' } if ($ref_type eq 'CODE');
+        return undef                    if ($ref_type ne 'HASH');
+        my @determined_array =
+            map {
+                my $stringized_value = dump_filtered($object_ref->{$_}, $filter);
+                my $value = eval $stringized_value;
+                ($_ => $value);
+            } sort keys %$object_ref;
+        return { dump => dump_filtered(\@determined_array, $filter) };
     };
     my $dumped_config = dump_filtered($self->config, $filter);
-    my $config = eval $dumped_config;
-    my @values = map { $config->{$_} } sort keys %$config;
-    my $hash = md5_base64(freeze(\@values));
+    my $hash = md5_base64($dumped_config);
     my $id = "$class/$hash";
 }
 
@@ -236,7 +248,7 @@ App::PerlWatcher::Watcher - Observes some external source of events and emits th
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 ATTRIBUTES
 
